pyxmpp.stanza

Package pyxmpp :: Module stanza |
[hide private]

# Module stanza

source code

General XMPP Stanza handling.

Normative reference:
  - RFC 3920

Classes | [hide private]
| Stanza Base class for all XMPP stanzas.

Functions | [hide private]
gen_id() Generate stanza id unique for the session. | source code

Variables | [hide private]
| __revision__ = ``'``$Id: stanza.py 714 2010-04-05 10:20:10Z jajcus $``'``
| last_id = `848638`
| __package__ = ``'``pyxmpp``'``

Imports: libxml2, random, xmlextra, from_utf8, to_utf8, JID, common_doc, common_ns, COMMON_NS, ProtocolError, JIDMalformedProtocolError

Function Details | [hide private]

### gen_id() | source code
Generate stanza id unique for the session. Returns: the new id.